from pathlib import Path
from typing import Optional

import pandas as pd

this_directory = Path(__file__).parent


class AbbrDecoder:
    def __init__(
        self, abbr_file_path: str = this_directory / "acronyms_ver0.1.csv"
    ) -> None:
        """
        Main class to decode abbreviation

        NOTE: Currently load the whole file because it's smol
        and lookup process will be faster. If the file became
        larger, lazy loading instead.
        """
        abbr_file = pd.read_csv(abbr_file_path)
        self.abbr_dict = dict(zip(abbr_file["acronym"], abbr_file["detail"]))

    def decode_abbr(self, abbr: str) -> Optional[str]:
        """
        Decode a single abbr.

        Returns:
            Optional[str]: Decoded abbr if searched successfully, else None
        """
        return self.abbr_dict.get(abbr)

    def decode_sentence(self, sentence: str) -> str:
        """
        Decode whole sentence

        Returns:
            str: Decoded sentence if abbr is searched successfully, else
        """
        tokens = sentence.split(" ")

        def _get_abbr_if_any(abbr: str):
            return self.abbr_dict.get(abbr, abbr)

        return " ".join(map(_get_abbr_if_any, tokens))



from distutils.core import setup
from pathlib import Path

this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

setup(
    name="abbrey",
    packages=["abbrey"],
    long_description=long_description,
    long_description_content_type="text/markdown",
    version="0.0.2",
    license="MIT",
    description="Abbreviation decoder",
    author="pdd",
    author_email="dungphamdang99@gmail.com",
    # url="https://github.com/user/reponame",  # TODO
    # download_url="https://github.com/user/reponame/archive/v_01.tar.gz",  # TODO
    keywords=["abbreviation"],
    install_requires=[
        "pandas",
    ],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Build Tools",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
    ],
    package_data={"abbrey": ["*.csv"]},
)
